@@ -1144,29 +1144,19 @@ distToNearest <- function(db, sequenceColumn="junction", vCallColumn="v_call", j
 #' 
 #' @examples
 #' \donttest{
-#' # Subset example data to one sample as a demo
+#' # Subset example data to 50 sequences, one sample and isotype as a demo
 #' data(ExampleDb, package="alakazam")
-#' db <- subset(ExampleDb, sample_id == "-1h")
+#' db <- subset(ExampleDb, sample_id == "-1h" & c_call=="IGHG")[1:50,]
 #' 
 #' # Use nucleotide Hamming distance and normalize by junction length
 #' db <- distToNearest(db, sequenceColumn="junction", vCallColumn="v_call",
 #'                     jCallColumn="j_call", model="ham", normalize="len", nproc=1)
 #'                             
-#' # Find threshold using the "gmm" method with optimal threshold
-#' output <- findThreshold(db$dist_nearest, method="gmm", model="gamma-gamma", cutoff="opt")
-#' plot(output, binwidth=0.02, title=paste0(output@model, "   loglk=", output@loglk))
-#' print(output)
-#'
 #' # Find threshold using the "gmm" method with user defined specificity
 #' output <- findThreshold(db$dist_nearest, method="gmm", model="gamma-gamma", 
 #'                         cutoff="user", spc=0.99)
 #' plot(output, binwidth=0.02, title=paste0(output@model, "   loglk=", output@loglk))
 #' print(output)
-#'
-#' # Find threshold using the "density" method and plot the results
-#' output <- findThreshold(db$dist_nearest, method="density")
-#' plot(output)
-#' print(output)
 #' }
 #' @export
 findThreshold <- function (distances, method=c("density", "gmm"), 
@@ -1266,7 +1256,7 @@ findThreshold <- function (distances, method=c("density", "gmm"),
     # gaussian_scaling <- (1/(4 * pi))^(1/10)
     
     # Ideal bandwidth
-    bandwidth <- kedd::h.ucv(unique(distances), 4)$h
+    bandwidth <- h.ucv(unique(distances), 4)$h
     #bandwidth <- kedd::h.ucv(distances, 4)$h
     #bandwidth <- ks::hucv(unique(distances), deriv.order=4)
     
