@@ -22,6 +22,7 @@
 #'   \item  \link{expectedMutations}:        Compute expected mutation frequencies.
 #'   \item  \link{shmulateSeq}:              Simulate mutations in a single sequence.
 #'   \item  \link{shmulateTree}:             Simulate mutations over a lineage tree.
+#'   \item  \link{setRegionBoundaries}:      Extends a region definition to include CDR3 and FWR4.
 #' }
 #' 
 #' @section  SHM targeting models:
@@ -112,6 +113,7 @@
 #'                          isValidAASeq translateStrings gridPlot
 #'                          getMRCA getPathLengths tableEdges
 #'                          progressBar baseTheme checkColumns cpuCount
+#'                          makeChangeoClone summarizeSubtrees buildPhylipLineage
 #' @importFrom  ape         mst
 #' @importFrom  diptest     dip.test
 #' @importFrom  doParallel  registerDoParallel
@@ -122,11 +124,12 @@
 #'                          mutate summarize
 #'                          mutate_at summarize_at
 #'                          rename transmute
+#'                          left_join recode pull
 #' @importFrom  foreach     foreach %dopar% registerDoSEQ
 #' @importFrom  igraph      V E as_adjacency_matrix graph_from_data_frame
-#'                          vertex_attr set_vertex_attr
+#'                          vertex_attr set_vertex_attr 
+#'                          layout_as_tree V<-
 #' @importFrom  iterators   icount
-#' @importFrom  kedd        h.ucv
 #' @importFrom  KernSmooth  bkde
 #' @importFrom  lazyeval    interp
 #' @importFrom  MASS        fitdistr
@@ -139,13 +142,13 @@
 #'                          approx convolve weighted.mean p.adjust
 #'                          dbeta pbeta qbeta rbeta optim optimize
 #'                          dnorm pnorm runif dgamma pgamma uniroot na.exclude
-#'                          as.dist cutree
+#'                          as.dist cutree integrate
 #' @importFrom  stringi     stri_dup stri_flatten stri_join stri_length 
 #'                          stri_sub stri_sub_replace stri_detect_regex
 #'                          stri_count_boundaries stri_count_regex 
 #'                          stri_extract_all_regex stri_extract_first_regex  
 #'                          stri_replace_all_regex stri_replace_first_regex
-#' @importFrom  tidyr       gather spread
+#' @importFrom  tidyr       gather spread pivot_wider
 #' @importFrom  tidyselect  all_of
 NULL
 
@@ -226,6 +229,11 @@ NULL
 # TODO: And what is this?
 # BAYESIAN_FITTED
 
+# IMGT-KABAT numbering mapping
+# As described hare http://www.imgt.org/IMGTScientificChart/Numbering/IMGT-Kabat_part1.html
+# CONVERT_NUM_REF
+
 # Add built-in variables to global variables environment
 utils::globalVariables(c("HH_S1F", "HKL_S1F", "MK_RS1NF",
-                         "HH_S5F", "HKL_S5F", "MK_RS5NF", "U5N"), package="shazam")
\ No newline at end of file
+                         "HH_S5F", "HKL_S5F", "MK_RS5NF", "U5N",
+                         "IMGT_V_BY_REGIONS"), package="shazam")
\ No newline at end of file
